@@ -1,5 +1,6 @@
 import os
 import sys
+from abc import ABC, abstractmethod
 
 import ijson
 
@@ -17,7 +18,7 @@ class StandardInputReader:
         return data.decode(self.encoding).encode('utf-8')
 
 
-class BaseCommand:
+class BaseCommand(ABC):
     kwargs = {}
 
     def __init__(self, subparsers):
@@ -27,18 +28,17 @@ class BaseCommand:
         self.subparser = subparsers.add_parser(self.name, description=self.help, **self.kwargs)
         self.add_base_arguments()
         self.add_arguments()
+        self.args = None
 
     def add_base_arguments(self):
         """
         Adds default arguments to all commands.
         """
-        pass
 
     def add_arguments(self):
         """
         Adds arguments specific to this command.
         """
-        pass
 
     def add_argument(self, *args, **kwargs):
         """
@@ -46,11 +46,11 @@ class BaseCommand:
         """
         self.subparser.add_argument(*args, **kwargs)
 
+    @abstractmethod
     def handle(self):
         """
         Runs the command.
         """
-        raise NotImplementedError('commands must implement handle()')
 
     def prefix(self):
         """
@@ -93,7 +93,7 @@ class BaseCommand:
             sys.exit(1)
 
 
-class OCDSCommand(BaseCommand):
+class OCDSCommand(BaseCommand, ABC):
     def add_base_arguments(self):
         self.add_argument('--root-path', type=str, default='',
                           help='the path to the items to process within each input')
