@@ -93,22 +93,22 @@ class Field:
         :param list sep: the separator to use in string representations of paths, overriding ``self.sep``
         :param list exclude: a list of keys to exclude from the dict
         """
-        d = {}
+        data = {}
 
         exclude = exclude or ()
         sep = sep or self.sep
 
-        for k, v in self.__dict__.items():
-            if k not in exclude and not k.startswith('_') and not k.endswith('_components'):
-                d[k] = v
-        for k in ('pointer', 'definition_pointer'):
-            if k not in exclude:
-                d[k] = getattr(self, k)
-        for k in ('path', 'definition_path'):
-            if k not in exclude:
-                d[k] = sep.join(getattr(self, '{}_components'.format(k)))
+        for key, value in self.__dict__.items():
+            if key not in exclude and not key.startswith('_') and not key.endswith('_components'):
+                data[key] = value
+        for key in ('pointer', 'definition_pointer'):
+            if key not in exclude:
+                data[key] = getattr(self, key)
+        for key in ('path', 'definition_path'):
+            if key not in exclude:
+                data[key] = sep.join(getattr(self, '{}_components'.format(key)))
 
-        return d
+        return data
 
 
 # This code is similar to `add_versioned` in `make_versioned_release_schema.py` in the `standard` repository.
@@ -144,8 +144,11 @@ def get_schema_fields(schema, pointer=None, path=None, definition_pointer=None,
         for offset in (2, 1):
             end = -LANGUAGE_CODE_SUFFIX_LEN - offset
             # The pattern must be anchored and the suffix must occur at the end.
-            if (key[end:-offset] == LANGUAGE_CODE_SUFFIX and
-                    key[:offset] == '^('[:offset] and key[-offset:] == ')$'[-offset:]):
+            if (
+                key[end:-offset] == LANGUAGE_CODE_SUFFIX
+                and key[:offset] == '^('[:offset]
+                and key[-offset:] == ')$'[-offset:]
+            ):
                 multilingual.add(key[offset:end])
                 hidden.add(key)
                 break
@@ -196,3 +199,35 @@ def _deprecated(value):
     if value is None:
         return {}
     return value.get('deprecated') or hasattr(value, '__reference__') and value.__reference__.get('deprecated') or {}
+
+
+def add_validation_properties(schema, unique_items=True):
+    """
+    Adds "minItems" and "uniqueItems" if an array, adds "minProperties" if an object, and adds "minLength" if a string
+    and if "enum", "format" and "pattern" aren't set.
+
+    :param dict schema: a JSON schema
+    :param bool unique_items: whether to add "uniqueItems" properties to array fields
+    """
+    if isinstance(schema, list):
+        for item in schema:
+            add_validation_properties(item, unique_items=unique_items)
+    elif isinstance(schema, dict):
+        if 'type' in schema:
+            if (
+                'string' in schema['type']
+                and 'enum' not in schema
+                and 'format' not in schema
+                and 'pattern' not in schema
+            ):
+                schema.setdefault('minLength', 1)
+            if 'array' in schema['type']:
+                schema.setdefault('minItems', 1)
+                if unique_items:
+                    schema.setdefault('uniqueItems', True)
+
+            if 'object' in schema['type']:
+                schema.setdefault('minProperties', 1)
+
+        for value in schema.values():
+            add_validation_properties(value, unique_items=unique_items)
