@@ -1,10 +1,13 @@
 import copy
 import json
 
+import pytest
+
 from ocdskit import oc4ids
 from tests import read
 
 
+@pytest.mark.vcr()
 def test_initial_tranform_state():
     releases = json.loads(read("release-package_additional-contact-points.json"))["releases"]
     transform_state = oc4ids.InitialTransformState(releases, "1")
@@ -12,6 +15,7 @@ def test_initial_tranform_state():
     assert len(transform_state.releases_by_ocid["ocds-213czf-1"]) == 2
 
 
+@pytest.mark.vcr()
 def test_run_all():
     releases = [
         {
@@ -26,6 +30,7 @@ def test_run_all():
     assert output["parties"] == releases[0]["parties"]
 
 
+@pytest.mark.vcr()
 def test_run_all_release_package():
     releases_package_1 = [
         {
@@ -58,6 +63,7 @@ def test_run_all_release_package():
     ]
 
 
+@pytest.mark.vcr()
 def test_public_authority_role():
     releases = [
         {
@@ -89,6 +95,7 @@ def test_public_authority_role():
     assert len(output["parties"]) == 1
 
 
+@pytest.mark.vcr()
 def test_duplicate_public_authority_role():
 
     # Match on identifier
@@ -180,6 +187,7 @@ def test_duplicate_public_authority_role():
     assert output["parties"][0]["id"] == "1"
 
 
+@pytest.mark.vcr()
 def test_buyer_role():
     releases = [
         {
@@ -197,6 +205,7 @@ def test_buyer_role():
     assert "buyer" in output["parties"][0]["roles"]
 
 
+@pytest.mark.vcr()
 def test_sector():
     releases = [
         {
@@ -235,6 +244,7 @@ def test_sector():
     assert set(output["sector"]) == set(["COFOG-04.5.1", "COFOG-2"])
 
 
+@pytest.mark.vcr()
 def test_additional_classifications():
     releases = [
         {
@@ -277,6 +287,7 @@ def test_additional_classifications():
     assert output["additionalClassifications"] == [{"scheme": "a", "id": "1"}, {"scheme": "a", "id": "2"}]
 
 
+@pytest.mark.vcr()
 def test_title():
     releases = [
         {
@@ -306,6 +317,7 @@ def test_title():
     assert "title" not in output
 
 
+@pytest.mark.vcr()
 def test_title_from_tender():
     releases = [
         {
@@ -350,6 +362,7 @@ def test_title_from_tender():
     assert output["title"] == releases[0]["planning"]["project"]["title"]
 
 
+@pytest.mark.vcr()
 def test_contracting_process_setup_releases():
     releases = [
         {
@@ -368,9 +381,7 @@ def test_contracting_process_setup_releases():
         },
     ]
 
-    output = oc4ids._run_transforms(
-        copy.deepcopy(releases), "1", transforms=[oc4ids.contracting_process_setup]
-    )
+    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.contracting_process_setup])
 
     expected = """
     {
@@ -417,6 +428,7 @@ def test_contracting_process_setup_releases():
     assert output == json.loads(expected)
 
 
+@pytest.mark.vcr()
 def test_contracting_process_setup_release_packages():
 
     releases = [
@@ -479,6 +491,7 @@ def test_contracting_process_setup_release_packages():
     assert output == json.loads(expected)
 
 
+@pytest.mark.vcr()
 def test_procuring_entity():
 
     releases = [
@@ -493,7 +506,7 @@ def test_procuring_entity():
     ]
 
     output = oc4ids._run_transforms(
-        copy.deepcopy(releases), "1", transforms=[oc4ids.contracting_process_setup, oc4ids.procuring_entity],
+        copy.deepcopy(releases), "1", transforms=[oc4ids.contracting_process_setup, oc4ids.procuring_entity]
     )
 
     assert output["parties"] == releases[0]["parties"]
@@ -510,7 +523,7 @@ def test_procuring_entity():
         },
     ]
     output = oc4ids._run_transforms(
-        copy.deepcopy(releases), "1", transforms=[oc4ids.contracting_process_setup, oc4ids.procuring_entity],
+        copy.deepcopy(releases), "1", transforms=[oc4ids.contracting_process_setup, oc4ids.procuring_entity]
     )
 
     assert output["parties"][0]["id"] == "1"
@@ -534,7 +547,7 @@ def test_procuring_entity():
         },
     ]
     output = oc4ids._run_transforms(
-        copy.deepcopy(releases), "1", transforms=[oc4ids.contracting_process_setup, oc4ids.procuring_entity],
+        copy.deepcopy(releases), "1", transforms=[oc4ids.contracting_process_setup, oc4ids.procuring_entity]
     )
 
     assert output["parties"][0]["id"] == "a-a"
@@ -558,7 +571,7 @@ def test_procuring_entity():
         },
     ]
     output = oc4ids._run_transforms(
-        copy.deepcopy(releases), "1", transforms=[oc4ids.contracting_process_setup, oc4ids.procuring_entity],
+        copy.deepcopy(releases), "1", transforms=[oc4ids.contracting_process_setup, oc4ids.procuring_entity]
     )
 
     assert output["parties"][0]["id"] == "1"
@@ -567,6 +580,7 @@ def test_procuring_entity():
     assert output["contractingProcesses"][1]["summary"]["tender"]["procuringEntity"]["id"] == "2"
 
 
+@pytest.mark.vcr()
 def test_administrative_entity():
 
     releases = [
@@ -580,15 +594,14 @@ def test_administrative_entity():
     ]
 
     output = oc4ids._run_transforms(
-        copy.deepcopy(releases),
-        "1",
-        transforms=[oc4ids.contracting_process_setup, oc4ids.administrative_entity],
+        copy.deepcopy(releases), "1", transforms=[oc4ids.contracting_process_setup, oc4ids.administrative_entity]
     )
 
     assert output["parties"] == releases[0]["parties"]
     assert output["contractingProcesses"][0]["summary"]["tender"]["administrativeEntity"] == {"id": "1", "name": "a"}
 
 
+@pytest.mark.vcr()
 def test_multiple_administrative_entity_in_process():
     releases = [
         {
@@ -604,9 +617,7 @@ def test_multiple_administrative_entity_in_process():
     ]
 
     output = oc4ids._run_transforms(
-        copy.deepcopy(releases),
-        "1",
-        transforms=[oc4ids.contracting_process_setup, oc4ids.administrative_entity],
+        copy.deepcopy(releases), "1", transforms=[oc4ids.contracting_process_setup, oc4ids.administrative_entity]
     )
 
     assert output["parties"] == releases[0]["parties"]
@@ -615,6 +626,7 @@ def test_multiple_administrative_entity_in_process():
     assert "tender" not in output["contractingProcesses"][0]["summary"]
 
 
+@pytest.mark.vcr()
 def test_contract_status_pre_award():
 
     releases = [
@@ -664,7 +676,7 @@ def test_contract_status_pre_award():
     ]
 
     output = oc4ids._run_transforms(
-        copy.deepcopy(releases), "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_status],
+        copy.deepcopy(releases), "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_status]
     )
 
     assert output["contractingProcesses"][0]["summary"]["status"] == "pre-award"
@@ -677,6 +689,7 @@ def test_contract_status_pre_award():
     assert output["contractingProcesses"][5]["summary"].get("status") != "pre-award"
 
 
+@pytest.mark.vcr()
 def test_contract_status_active():
 
     releases = [
@@ -724,7 +737,7 @@ def test_contract_status_active():
     ]
 
     output = oc4ids._run_transforms(
-        copy.deepcopy(releases), "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_status],
+        copy.deepcopy(releases), "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_status]
     )
 
     assert output["contractingProcesses"][0]["summary"]["status"] == "active"
@@ -737,6 +750,7 @@ def test_contract_status_active():
     assert output["contractingProcesses"][4]["summary"]["status"] == "active"
 
 
+@pytest.mark.vcr()
 def test_contract_status_closed():
 
     releases = [
@@ -802,7 +816,7 @@ def test_contract_status_closed():
     ]
 
     output = oc4ids._run_transforms(
-        copy.deepcopy(releases), "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_status],
+        copy.deepcopy(releases), "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_status]
     )
 
     assert output["contractingProcesses"][0]["summary"]["status"] == "closed"
@@ -814,6 +828,7 @@ def test_contract_status_closed():
     assert output["contractingProcesses"][6]["summary"]["status"] != "closed"
 
 
+@pytest.mark.vcr()
 def test_procurment_process():
 
     releases = [
@@ -827,14 +842,13 @@ def test_procurment_process():
     ]
 
     output = oc4ids._run_transforms(
-        copy.deepcopy(releases),
-        "1",
-        transforms=[oc4ids.contracting_process_setup, oc4ids.procurement_process],
+        copy.deepcopy(releases), "1", transforms=[oc4ids.contracting_process_setup, oc4ids.procurement_process]
     )
 
     assert output["contractingProcesses"][0]["summary"]["tender"] == releases[0]["tender"]
 
 
+@pytest.mark.vcr()
 def test_number_of_tenderers():
 
     releases = [
@@ -848,14 +862,13 @@ def test_number_of_tenderers():
     ]
 
     output = oc4ids._run_transforms(
-        copy.deepcopy(releases),
-        "1",
-        transforms=[oc4ids.contracting_process_setup, oc4ids.number_of_tenderers],
+        copy.deepcopy(releases), "1", transforms=[oc4ids.contracting_process_setup, oc4ids.number_of_tenderers]
     )
 
     assert output["contractingProcesses"][0]["summary"]["tender"]["numberOfTenderers"] == 123
 
 
+@pytest.mark.vcr()
 def test_location():
     releases = [
         {
@@ -867,11 +880,12 @@ def test_location():
         }
     ]
 
-    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.location],)
+    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.location])
 
     assert output["locations"] == [{"description": "Mars"}]
 
 
+@pytest.mark.vcr()
 def test_location_multiple_releases():
     releases = [
         {
@@ -890,11 +904,12 @@ def test_location_multiple_releases():
         },
     ]
 
-    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.location],)
+    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.location])
 
     assert output["locations"] == [{"description": "Mars"}, {"description": "Jupiter"}, {"description": "Earth"}]
 
 
+@pytest.mark.vcr()
 def test_location_from_item_location():
     releases = [
         {
@@ -917,11 +932,12 @@ def test_location_from_item_location():
     ]
 
     output = oc4ids._run_transforms(
-        copy.deepcopy(releases), "1", transforms=[oc4ids.location, oc4ids.location_from_items],
+        copy.deepcopy(releases), "1", transforms=[oc4ids.location, oc4ids.location_from_items]
     )
     assert output["locations"] == [releases[0]["tender"]["items"][0]["deliveryLocation"]]
 
 
+@pytest.mark.vcr()
 def test_location_from_delivery_address():
     releases = [
         {
@@ -947,12 +963,13 @@ def test_location_from_delivery_address():
     ]
 
     output = oc4ids._run_transforms(
-        copy.deepcopy(releases), "1", transforms=[oc4ids.location, oc4ids.location_from_items],
+        copy.deepcopy(releases), "1", transforms=[oc4ids.location, oc4ids.location_from_items]
     )
 
     assert output["locations"] == [{"address": releases[0]["tender"]["items"][0]["deliveryAddress"]}]
 
 
+@pytest.mark.vcr()
 def test_location_multiple():
     releases = [
         {
@@ -982,7 +999,7 @@ def test_location_multiple():
     ]
 
     output = oc4ids._run_transforms(
-        copy.deepcopy(releases), "1", transforms=[oc4ids.location, oc4ids.location_from_items],
+        copy.deepcopy(releases), "1", transforms=[oc4ids.location, oc4ids.location_from_items]
     )
 
     assert output["locations"] == [
@@ -991,6 +1008,7 @@ def test_location_multiple():
     ]
 
 
+@pytest.mark.vcr()
 def test_location_not_inferred():
     releases = [
         {
@@ -1019,11 +1037,12 @@ def test_location_not_inferred():
         }
     ]
 
-    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.location],)
+    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.location])
 
     assert "locations" not in output
 
 
+@pytest.mark.vcr()
 def test_budget():
     releases = [
         {
@@ -1035,10 +1054,11 @@ def test_budget():
         }
     ]
 
-    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.budget],)
+    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.budget])
     assert output["budget"]["amount"] == releases[0]["planning"]["budget"]["amount"]
 
 
+@pytest.mark.vcr()
 def test_budget_multiple():
     releases = [
         {
@@ -1057,7 +1077,7 @@ def test_budget_multiple():
         },
     ]
 
-    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.budget],)
+    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.budget])
     total = float(releases[0]["planning"]["budget"]["amount"]["amount"]) + float(
         releases[1]["planning"]["budget"]["amount"]["amount"]
     )
@@ -1065,6 +1085,7 @@ def test_budget_multiple():
     assert output["budget"]["amount"]["currency"] == releases[0]["planning"]["budget"]["amount"]["currency"]
 
 
+@pytest.mark.vcr()
 def test_budget_fail():
     releases = [
         {
@@ -1083,11 +1104,12 @@ def test_budget_fail():
         },
     ]
 
-    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.budget],)
+    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.budget])
     # Different currencies could not be totalled
     assert "budget" not in output
 
 
+@pytest.mark.vcr()
 def test_budget_approval():
     releases = [
         {
@@ -1104,7 +1126,7 @@ def test_budget_approval():
         },
     ]
 
-    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.budget_approval],)
+    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.budget_approval])
     assert output["documents"] == [releases[0]["planning"]["documents"][1]]
 
     # duplicate document id in different process, auto increment new doc ids.
@@ -1120,13 +1142,14 @@ def test_budget_approval():
         }
     )
 
-    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.budget_approval],)
+    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.budget_approval])
 
     assert len(output["documents"]) == 2
     assert output["documents"][0]["id"] == "1"
     assert output["documents"][1]["id"] == "2"
 
 
+@pytest.mark.vcr()
 def test_purpose_one():
     releases = [
         {
@@ -1138,10 +1161,11 @@ def test_purpose_one():
         },
     ]
 
-    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.purpose],)
+    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.purpose])
     assert output["purpose"] == releases[0]["planning"]["rationale"]
 
 
+@pytest.mark.vcr()
 def test_purpose_multiple():
     releases = [
         {
@@ -1162,10 +1186,11 @@ def test_purpose_multiple():
 
     rationales = "<ocds-213czf-1> We were hungry.\n<ocds-213czf-2> There are never enough post-its.\n"
 
-    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.purpose],)
+    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.purpose])
     assert output["purpose"] == rationales
 
 
+@pytest.mark.vcr()
 def test_needs_assessment():
     releases = [
         {
@@ -1182,12 +1207,11 @@ def test_needs_assessment():
         },
     ]
 
-    output = oc4ids._run_transforms(
-        copy.deepcopy(releases), "1", transforms=[oc4ids.purpose_needs_assessment],
-    )
+    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.purpose_needs_assessment])
     assert output["documents"] == [releases[0]["planning"]["documents"][0]]
 
 
+@pytest.mark.vcr()
 def test_description_one():
     releases = [
         {
@@ -1199,10 +1223,11 @@ def test_description_one():
         },
     ]
 
-    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.description],)
+    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.description])
     assert output["description"] == releases[0]["planning"]["project"]["description"]
 
 
+@pytest.mark.vcr()
 def test_description_multiple():
     releases = [
         {
@@ -1221,17 +1246,18 @@ def test_description_multiple():
         },
     ]
 
-    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.description],)
+    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.description])
     assert output["description"] == releases[0]["planning"]["project"]["description"]
 
     # contraditing descriptions
     releases[0]["planning"]["project"]["description"] = "another description"
 
-    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.description],)
+    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.description])
 
     assert "description" not in output
 
 
+@pytest.mark.vcr()
 def test_description_tender():
     releases = [
         {
@@ -1244,7 +1270,7 @@ def test_description_tender():
     ]
 
     output = oc4ids._run_transforms(
-        copy.deepcopy(releases), "1", transforms=[oc4ids.description, oc4ids.description_tender],
+        copy.deepcopy(releases), "1", transforms=[oc4ids.description, oc4ids.description_tender]
     )
     assert output["description"] == releases[0]["tender"]["description"]
 
@@ -1258,13 +1284,14 @@ def test_description_tender():
         }
     )
     output = oc4ids._run_transforms(
-        copy.deepcopy(releases), "1", transforms=[oc4ids.description, oc4ids.description_tender],
+        copy.deepcopy(releases), "1", transforms=[oc4ids.description, oc4ids.description_tender]
     )
     assert (
         output["description"] == "<ocds-213czf-1> A project description\n<ocds-213czf-2> A new project description\n"
     )
 
 
+@pytest.mark.vcr()
 def test_description_not_tender():
     releases = [
         {
@@ -1278,11 +1305,12 @@ def test_description_not_tender():
     ]
 
     output = oc4ids._run_transforms(
-        copy.deepcopy(releases), "1", transforms=[oc4ids.description, oc4ids.description_tender],
+        copy.deepcopy(releases), "1", transforms=[oc4ids.description, oc4ids.description_tender]
     )
     assert output["description"] == releases[0]["planning"]["project"]["description"]
 
 
+@pytest.mark.vcr()
 def test_environmental_impact():
     releases = [
         {
@@ -1299,10 +1327,11 @@ def test_environmental_impact():
         },
     ]
 
-    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.environmental_impact],)
+    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.environmental_impact])
     assert output["documents"] == [releases[0]["planning"]["documents"][0]]
 
 
+@pytest.mark.vcr()
 def test_land_and_settlement_impact():
     releases = [
         {
@@ -1319,12 +1348,11 @@ def test_land_and_settlement_impact():
         },
     ]
 
-    output = oc4ids._run_transforms(
-        copy.deepcopy(releases), "1", transforms=[oc4ids.land_and_settlement_impact],
-    )
+    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.land_and_settlement_impact])
     assert output["documents"] == [releases[0]["planning"]["documents"][1]]
 
 
+@pytest.mark.vcr()
 def test_project_scope():
     releases = [
         {
@@ -1341,10 +1369,11 @@ def test_project_scope():
         },
     ]
 
-    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.project_scope],)
+    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.project_scope])
     assert output["documents"] == [releases[0]["planning"]["documents"][0]]
 
 
+@pytest.mark.vcr()
 def test_project_scope_summary():
     releases = [
         {
@@ -1361,7 +1390,7 @@ def test_project_scope_summary():
     ]
 
     output = oc4ids._run_transforms(
-        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.project_scope_summary],
+        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.project_scope_summary]
     )
 
     assert "items" in output["contractingProcesses"][0]["summary"]["tender"]
@@ -1370,6 +1399,7 @@ def test_project_scope_summary():
     assert output["contractingProcesses"][0]["summary"]["tender"]["milestones"] == releases[0]["tender"]["milestones"]
 
 
+@pytest.mark.vcr()
 def test_funders_budget():
     releases = [
         {
@@ -1414,13 +1444,14 @@ def test_funders_budget():
         }
     ]
 
-    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.funding_sources],)
+    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.funding_sources])
 
     assert output["parties"][0]["id"] == "GB-LAC-E09000003-557"
     assert output["parties"][0]["details"] == "This is just a test."
     assert "funder" in output["parties"][0]["roles"]
 
 
+@pytest.mark.vcr()
 def test_funders():
     releases = [
         {
@@ -1445,13 +1476,14 @@ def test_funders():
         }
     ]
 
-    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.funding_sources],)
+    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.funding_sources])
 
     assert output["parties"][0]["id"] == "GB-LAC-E09000003-557"
     assert output["parties"][0]["details"] == "This is just a test."
     assert "funder" in output["parties"][0]["roles"]
 
 
+@pytest.mark.vcr()
 def test_cost_estimate():
 
     releases = [
@@ -1471,18 +1503,14 @@ def test_cost_estimate():
         },
     ]
 
-    output = oc4ids._run_transforms(
-        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.cost_estimate],
-    )
+    output = oc4ids._run_transforms(releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.cost_estimate])
 
     assert output["contractingProcesses"][0]["summary"]["tender"]["costEstimate"] == {"amount": 10}
 
     # reverse releases
     releases[0]["date"], releases[1]["date"] = releases[1]["date"], releases[0]["date"]
 
-    output = oc4ids._run_transforms(
-        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.cost_estimate],
-    )
+    output = oc4ids._run_transforms(releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.cost_estimate])
 
     assert output["contractingProcesses"][0]["summary"]["tender"]["costEstimate"] == {"amount": 1}
 
@@ -1497,12 +1525,11 @@ def test_cost_estimate():
     )
 
     # last releases is not planning
-    output = oc4ids._run_transforms(
-        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.cost_estimate],
-    )
+    output = oc4ids._run_transforms(releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.cost_estimate])
     assert output["contractingProcesses"][0]["summary"]["tender"]["costEstimate"] == {"amount": 1}
 
 
+@pytest.mark.vcr()
 def test_contract_title():
 
     releases = [
@@ -1518,7 +1545,7 @@ def test_contract_title():
     ]
 
     output = oc4ids._run_transforms(
-        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_title],
+        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_title]
     )
 
     assert output["contractingProcesses"][0]["summary"]["title"] == "a"
@@ -1527,7 +1554,7 @@ def test_contract_title():
     releases[0]["contracts"].append({"title": "a"})
 
     output = oc4ids._run_transforms(
-        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_title],
+        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_title]
     )
 
     assert output["contractingProcesses"][0]["summary"]["title"] == "c"
@@ -1536,12 +1563,13 @@ def test_contract_title():
     releases[0].pop("contracts")
 
     output = oc4ids._run_transforms(
-        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_title],
+        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_title]
     )
 
     assert output["contractingProcesses"][0]["summary"]["title"] == "b"
 
 
+@pytest.mark.vcr()
 def test_supplier():
 
     releases = [
@@ -1557,9 +1585,7 @@ def test_supplier():
         }
     ]
 
-    output = oc4ids._run_transforms(
-        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.suppliers],
-    )
+    output = oc4ids._run_transforms(releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.suppliers])
 
     assert output["parties"] == releases[0]["parties"]
 
@@ -1569,6 +1595,7 @@ def test_supplier():
     ]
 
 
+@pytest.mark.vcr()
 def test_contract_value():
 
     releases = [
@@ -1586,7 +1613,7 @@ def test_contract_value():
     ]
 
     output = oc4ids._run_transforms(
-        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_price],
+        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_price]
     )
 
     assert output["contractingProcesses"][0]["summary"]["contractValue"] == {"amount": 30, "currency": "USD"}
@@ -1595,12 +1622,13 @@ def test_contract_value():
     releases[0]["awards"][1]["value"]["currency"] = "CAD"
 
     output = oc4ids._run_transforms(
-        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_price],
+        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_price]
     )
 
     assert "contractValue" not in output["contractingProcesses"][0]["summary"]
 
 
+@pytest.mark.vcr()
 def test_contracting_process_description():
 
     releases = [
@@ -1616,7 +1644,7 @@ def test_contracting_process_description():
     ]
 
     output = oc4ids._run_transforms(
-        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_process_description],
+        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_process_description]
     )
 
     assert output["contractingProcesses"][0]["summary"]["description"] == "a"
@@ -1625,7 +1653,7 @@ def test_contracting_process_description():
     releases[0]["contracts"][0].pop("description")
 
     output = oc4ids._run_transforms(
-        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_process_description],
+        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_process_description]
     )
 
     assert output["contractingProcesses"][0]["summary"]["description"] == "item_a"
@@ -1634,7 +1662,7 @@ def test_contracting_process_description():
     releases[0].pop("contracts")
 
     output = oc4ids._run_transforms(
-        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_process_description],
+        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_process_description]
     )
 
     assert output["contractingProcesses"][0]["summary"]["description"] == "b"
@@ -1643,7 +1671,7 @@ def test_contracting_process_description():
     releases[0]["awards"][0].pop("description")
 
     output = oc4ids._run_transforms(
-        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_process_description],
+        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_process_description]
     )
 
     assert output["contractingProcesses"][0]["summary"]["description"] == "item_b"
@@ -1653,7 +1681,7 @@ def test_contracting_process_description():
     releases[0]["awards"][0]["items"].append({"description": "item_b"})
 
     output = oc4ids._run_transforms(
-        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_process_description],
+        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_process_description]
     )
 
     assert "description" not in output["contractingProcesses"][0]["summary"]
@@ -1662,7 +1690,7 @@ def test_contracting_process_description():
     releases[0]["awards"].append({"description": "b"})
 
     output = oc4ids._run_transforms(
-        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_process_description],
+        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_process_description]
     )
 
     assert output["contractingProcesses"][0]["summary"]["description"] == "c"
@@ -1671,7 +1699,7 @@ def test_contracting_process_description():
     releases[0]["tender"].pop("description")
 
     output = oc4ids._run_transforms(
-        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_process_description],
+        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_process_description]
     )
 
     assert output["contractingProcesses"][0]["summary"]["description"] == "item_c"
@@ -1680,12 +1708,13 @@ def test_contracting_process_description():
     releases[0]["tender"]["items"].append({"description": "item_c"})
 
     output = oc4ids._run_transforms(
-        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_process_description],
+        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_process_description]
     )
 
     assert "description" not in output["contractingProcesses"][0]["summary"]
 
 
+@pytest.mark.vcr()
 def test_contracting_period():
 
     releases = [
@@ -1703,7 +1732,7 @@ def test_contracting_period():
     ]
 
     output = oc4ids._run_transforms(
-        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_period],
+        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_period]
     )
 
     assert output["contractingProcesses"][0]["summary"]["contractPeriod"] == {
@@ -1715,12 +1744,13 @@ def test_contracting_period():
     releases[0].pop("awards")
 
     output = oc4ids._run_transforms(
-        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_period],
+        releases, "1", transforms=[oc4ids.contracting_process_setup, oc4ids.contract_period]
     )
 
     assert output["contractingProcesses"][0]["summary"]["contractPeriod"] == releases[0]["tender"]["contractPeriod"]
 
 
+@pytest.mark.vcr()
 def test_final_audit():
     releases = [
         {
@@ -1749,7 +1779,7 @@ def test_final_audit():
         },
     ]
 
-    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.final_audit],)
+    output = oc4ids._run_transforms(copy.deepcopy(releases), "1", transforms=[oc4ids.final_audit])
     assert output["documents"] == [
         releases[0]["contracts"][0]["implementation"]["documents"][0],
         releases[0]["contracts"][1]["implementation"]["documents"][0],
